Class: Guard::Plugin

Inherits:
Object
  • Object
show all
Defined in:
lib/guard/compat/test/helper.rb,
lib/guard/compat/plugin.rb

Overview

Monkey patch Plugin to just keep the interface

Direct Known Subclasses

MyPlugin

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ Plugin

Returns a new instance of Plugin.



14
15
16
17
18
# File 'lib/guard/compat/plugin.rb', line 14

def initialize(_options = {})
  msg = 'either Guard has not been required or you did not' \
    ' include guard/compat/test/helper'
  fail NotImplementedError, msg
end

Instance Attribute Details

#optionsObject (readonly)

Returns the value of attribute options.



8
9
10
# File 'lib/guard/compat/test/helper.rb', line 8

def options
  @options
end

Instance Method Details

#old_initializePlugin

Returns a new instance of Plugin.

Returns:

  • (Plugin)

    a new instance of Plugin



10
11
12
13
14
# File 'lib/guard/compat/test/helper.rb', line 10

def initialize(_options = {})
  msg = 'either Guard has not been required or you did not' \
    ' include guard/compat/test/helper'
  fail NotImplementedError, msg
end