Class: Guard::Plugin
- Inherits:
-
Object
- Object
- Guard::Plugin
- Defined in:
- lib/guard/compat/test/helper.rb,
lib/guard/compat/plugin.rb
Overview
Monkey patch Plugin to just keep the interface
Direct Known Subclasses
Instance Attribute Summary collapse
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#initialize(options = {}) ⇒ Plugin
constructor
A new instance of Plugin.
-
#old_initialize ⇒ Plugin
A new instance of Plugin.
Constructor Details
#initialize(options = {}) ⇒ Plugin
Returns a new instance of Plugin.
14 15 16 17 18 |
# File 'lib/guard/compat/plugin.rb', line 14 def initialize( = {}) msg = 'either Guard has not been required or you did not' \ ' include guard/compat/test/helper' fail NotImplementedError, msg end |
Instance Attribute Details
#options ⇒ Object (readonly)
Returns the value of attribute options.
8 9 10 |
# File 'lib/guard/compat/test/helper.rb', line 8 def @options end |
Instance Method Details
#old_initialize ⇒ Plugin
Returns a new instance of Plugin.
10 11 12 13 14 |
# File 'lib/guard/compat/test/helper.rb', line 10 def initialize( = {}) msg = 'either Guard has not been required or you did not' \ ' include guard/compat/test/helper' fail NotImplementedError, msg end |